Rails.application.routes.draw do
  concern :range_searchable, BlacklightRangeLimit::Routes::RangeSearchable.new
  mount Bulkrax::Engine, at: '/'
  mount Riiif::Engine => 'images', as: :riiif if Hyrax.config.iiif_image_server?
        mount BrowseEverything::Engine => '/browse'

  mount Blacklight::Engine => '/'
  
  concern :searchable, Blacklight::Routes::Searchable.new

  resource :catalog, only: [:index], as: 'catalog', path: '/catalog', controller: 'catalog' do
    concerns :searchable
    concerns :range_searchable

  end
  devise_for :users, controllers: { omniauth_callbacks: 'callbacks' }

  devise_scope :user do
    get "users/system_sign_in", :to => "sessions#system_sign_in"
    get 'users/:id', :to => "users#show"
  end

  get 'dashboard/profiles/:id', :to => 'profiles#show'

  mount Hydra::RoleManagement::Engine => '/'

  authenticate :user, lambda { |u| u.admin? } do
    require 'sidekiq/web'
    mount Sidekiq::Web => '/sidekiq'
  end

  mount Qa::Engine => '/authorities'
  mount Hyrax::Engine, at: '/'
  resources :welcome, only: 'index'
  root 'hyrax/homepage#index'
  curation_concerns_basic_routes
  concern :exportable, Blacklight::Routes::Exportable.new

  resources :solr_documents, only: [:show], path: '/catalog', controller: 'catalog' do
    concerns :exportable
  end
  resources :download_all, only: :show

  resources :bookmarks do
    concerns :exportable

    collection do
      delete 'clear'
    end
  end

  get "/404", to: "errors#not_found", via: :all
  get "/500", to: "errors#internal_server_error", via: :all
  get "/422", to: "errors#unprocessable_entity", via: :all
  get "/403", to: "errors#access_forbidden", via: :all
  

  # For details on the DSL available within this file, see http://guides.rubyonrails.org/routing.html
end

Bulkrax::Engine.routes.draw do
  concern :range_searchable, BlacklightRangeLimit::Routes::RangeSearchable.new
  post 'rerun_failed_entries', to: "rerun_importers#rerun_failed_entries"
  post 'marked_as_complete', to: "rerun_importers#marked_as_complete"
end

Hyrax::Engine.routes.draw do
  concern :range_searchable, BlacklightRangeLimit::Routes::RangeSearchable.new

  scope :concern, module: :crc_datasets do
    resources :crc_datasets, only: [] do
      resources :complex_sessions do
        get :validate_session_title, on: :collection
      end
      resources :complex_subjects do
        get :validate_subject_title, on: :collection
      end
      resources :complex_modalities do
        get :validate_modality_title, on: :collection
      end
    end
  end
end
